summaryrefslogtreecommitdiffstats
path: root/smb4k/configdlg/smb4kconfigdialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'smb4k/configdlg/smb4kconfigdialog.h')
-rw-r--r--smb4k/configdlg/smb4kconfigdialog.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/smb4k/configdlg/smb4kconfigdialog.h b/smb4k/configdlg/smb4kconfigdialog.h
index 4681df2..4a87dc8 100644
--- a/smb4k/configdlg/smb4kconfigdialog.h
+++ b/smb4k/configdlg/smb4kconfigdialog.h
@@ -57,11 +57,11 @@ class Smb4KConfigDialog : public KConfigDialog
* @param settings The Smb4KSettings object that needs to be passed
* so that the settings can be managed.
*
* @param tqparent The tqparent widget
*
* @param name The name of this dialog
*/
- Smb4KConfigDialog( Smb4KSettings *settings, TQWidget *tqparent = 0, const char *name = 0 );
+ Smb4KConfigDialog( Smb4KSettings *settings, TQWidget *parent = 0, const char *name = 0 );
/**
* The destructor
@@ -191,7 +191,7 @@ class Smb4KConfigDialogFactory : KLibFactory
static KInstance *instance();
protected:
- TQObject *createObject( TQObject *tqparent = 0, const char *name = 0,
+ TQObject *createObject( TQObject *parent = 0, const char *name = 0,
const char *classname = TQOBJECT_OBJECT_NAME_STRING,
const TQStringList &args = TQStringList() );
@@ -57,11 +57,11 @@ class Smb4KConfigDialog : public KConfigDialog
* so that the settings can be managed.
*
- * @param tqparent The tqparent widget
+ * @param parent The parent widget
*
* @param name The name of this dialog